aboutsummaryrefslogtreecommitdiff
path: root/src/emitter.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/emitter.rs')
-rw-r--r--src/emitter.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/emitter.rs b/src/emitter.rs
index ccc5a60..2a47f40 100644
--- a/src/emitter.rs
+++ b/src/emitter.rs
@@ -17,15 +17,15 @@ use crate::Error;
/// doesn't mean you need to follow it. For example:
///
/// * If your usage of the tokenizer will ignore all errors, none of the error handling and
/// validation requirements apply to you. You can implement `emit_error` as noop and omit all
/// checks that would emit errors.
///
/// * If you don't care about attributes at all, you can make all related methods a noop.
#[allow(unused_variables)] // workaround for https://github.com/rust-lang/rust/issues/91074
pub trait Emitter<O> {
- /// A (probably recoverable) parsing error has occurred.
- fn emit_error(&mut self, error: Error, span: Range<O>);
+ /// Reports a parse error.
+ fn report_error(&mut self, error: Error, span: Range<O>);
/// The state machine has reached the end of the file.
fn emit_eof(&mut self);
@@ -17,15 +17,15 @@ use crate::Error;
///
/// * If your usage of the tokenizer will ignore all errors, none of the error handling and
-/// validation requirements apply to you. You can implement `emit_error` as noop and omit all
+/// validation requirements apply to you. You can implement `report_error` as noop and omit all
/// checks that would emit errors.
///